pub fn amplitude(field: ArrayView2<'_, Complex64>) -> Array2<f64>Expand description
Computes amplitude from any logical two-dimensional layout.
The returned array is newly allocated in standard row-major order.
pub fn amplitude(field: ArrayView2<'_, Complex64>) -> Array2<f64>Computes amplitude from any logical two-dimensional layout.
The returned array is newly allocated in standard row-major order.