pub fn phase(field: ArrayView2<'_, Complex64>) -> Array2<f64>Expand description
Computes phase from any logical two-dimensional layout.
The returned array is newly allocated in standard row-major order.
pub fn phase(field: ArrayView2<'_, Complex64>) -> Array2<f64>Computes phase from any logical two-dimensional layout.
The returned array is newly allocated in standard row-major order.